#
# spec file for package plasma5-systemmonitor
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.98.0
%bcond_without released
Name:           plasma5-systemmonitor
Version:        5.27.10
Release:        1.2
Summary:        An application for monitoring system resources
License:        GPL-3.0-only
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/plasma/%{version}/plasma-systemmonitor-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-systemmonitor-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules >= %{kf5_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config) >= %{kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Declarative) >= %{kf5_version}
BuildRequires:  cmake(KF5GlobalAccel) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5ItemModels) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5NewStuff) >= %{kf5_version}
BuildRequires:  cmake(KF5Service) >= %{kf5_version}
BuildRequires:  cmake(KSysGuard)
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Widgets)
Requires:       kdeclarative-components
Requires:       kirigami2
Requires:       kitemmodels-imports
Requires:       knewstuff-imports
Requires:       kquickcharts
Requires:       ksystemstats5
Requires:       libqt5-qtquickcontrols2
Requires:       qqc2-desktop-style

%description
plasma-systemmonitor provides an interface for monitoring system sensors,
process information and other system resources.

%lang_package

%prep
%autosetup -p1 -n plasma-systemmonitor-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%make_install -C build
%suse_update_desktop_file org.kde.plasma-systemmonitor System Monitor

%fdupes %{buildroot}/%{_kf5_sharedir}

%find_lang %{name} --with-man --all-name

%files
%license LICENSES/*
%doc README.md
%{_kf5_bindir}/plasma-systemmonitor
%dir %{_kf5_qmldir}/org/kde/ksysguard/
%{_kf5_qmldir}/org/kde/ksysguard/page/
%{_kf5_qmldir}/org/kde/ksysguard/table/
%{_kf5_applicationsdir}/org.kde.plasma-systemmonitor.desktop
%{_kf5_configkcfgdir}/systemmonitor.kcfg
%{_kf5_knsrcfilesdir}/plasma-systemmonitor.knsrc
%dir %{_kf5_sharedir}/ksysguard/
%{_kf5_sharedir}/ksysguard/sensorfaces/
%{_kf5_sharedir}/plasma-systemmonitor/
%dir %{_kf5_sharedir}/plasma/
%dir %{_kf5_sharedir}/plasma/kinfocenter/
%dir %{_kf5_sharedir}/plasma/kinfocenter/externalmodules/
%{_kf5_sharedir}/plasma/kinfocenter/externalmodules/kcm_external_plasma-systemmonitor.desktop
%{_kf5_appstreamdir}/org.kde.plasma-systemmonitor.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- No code changes since 5.27.9
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- No code changes since 5.27.8
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- Changes since 5.27.7:
  * Hide heightHelper BasicListItem
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- No code changes since 5.27.6
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- Changes since 5.27.5:
  * Fix layout of Add New Page dialog with wordy languages (kde#470726)
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- No code changes since 5.27.4
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- No code changes since 5.27.2
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- No code changes since 5.27.0
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- Changes since 5.26.90:
  * Set RemoveDeadEntries=true in the pages knsrc (kde#453651)
  * table: Workaround a memory leak in QQmlPropertyCache (kde#460370)
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * Process table: Always use binary name for icon lookup (kde#454326)
  * Add missing KWindowSystem link
  * applicationstable: Use the same scaling for CPU details as the column display (kde#462775)
  * table: Don't clear the selection when setting current index (kde#460615)
  * Be more explicit in kill button texts (kde#454753)
  * port all headers to pragma once
  * Slightly reduce minimum window size (kde#462803)
  * Convert hardcoded minimum sizes to multiples of GridUnit
  * Use ecm_set_disabled_deprecation_versions
  * Perform initialization in initialization list
  * Remove invalid appstream releases
  * Install po folder
  * Move DialogLoader to data of ScrollablePage (kde#459514)
  * Set QSurfaceFormat::ResetNotification
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * Install po folder
  * Move DialogLoader to data of ScrollablePage (kde#459514)
  * Set QSurfaceFormat::ResetNotification
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Install metainfo file
  * Remove dot from appstream summary
  * Add FreeBSD Qt6 CI support
  * Add reuse CI
  * Doc: Remove outdated requirements section from README.md
  * Add keywords for common search terms
  * Use new ECMFindQmlModule
  * Request passing unit tests on Linux and BSD
  * Use the new dialog for replacing missing sensors
  * Display a message when sensors are missing from a page
  * Add a dialog to display missing sensors and what to replace them with
  * Use JavaScript strict equality ===
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- No code changes since 5.24.90
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Fix activating running instance on Wayland
  * Set loadType to onstart for history page
  * Add a page option to allow preloading a page (kde#440402)
  * REmove duplicate header between header/file
  * Remove explicit QuickSettings init method call
  * Add CI support
  * It's enabled by default in qt6
  * Fix compile against qt6
  * Allow to build against qt6
  * Do not use Control as container for config UI elements
  * Set "noMargins" to true for Applications and Processes pages (kde#447146)
  * Mark as single window app
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * Do not use Control as container for config UI elements
  * Set "noMargins" to true for Applications and Processes pages (kde#447146)
  * Mark as single window app
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * Fix clazy warnings
  * Fix some clazy warnings
  * Fix some cppcheck warnings
  * Remove unused variable
  * Strip punctuation of labels in config
  * Add comma separated filtering to ApplicationsTableView
  * ApplicationsTable: Remove unneeded ProcessSortFilterModel (kde#445544)
  * Add GitLab CI
  * Don't make right click popup modal
  * Fix main.qml URL from not being a URL
  * Port away from Kirigami.Units.devicePixelRatio
  * Move spinbox below label in Sensor settings to avoid getting cut off
  * Allow changing row heights to one of three different modes (kde#441489)
  * Clarify that the KSysGuard package is libksysguard
  * Find KSystemStats
  * Install external kinfocenter module in ${KDE_INSTALL_DATADIR}/plasma/kinfocenter/externalmodules
  * Add .kde-ci.yml
  * add external infocenter module
  * Avoid basing a preferredWidth on a currentWidth
  * No need to build a custom string for the application window title
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- Changes since 5.23.4:
  * Add comma separated filtering to ApplicationsTableView
  * ApplicationsTable: Remove unneeded ProcessSortFilterModel (kde#445544)
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- Changes since 5.23.3:
  * Don't make right click popup modal
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * Avoid basing a preferredWidth on a currentWidth
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Too many changes to list here
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- Changes since 5.22.4:
  * Fix page export (kde#440551)
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- Changes since 5.22.2.1:
  * Pass parent index when fetching selection data (kde#438626)
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- Changes since 5.22.0:
  * Clear layers when navigating
  * Switch away from removed pages (kde#437499)
  * Do not reset the start page if the model changes
  * Fix binding loop and null derefence warnings in EditablePage::heightForContent
  * Fix GCC warning about copying an element from a container
  * Use entryEvent signal for reacting to GHNS changes
  * Push NewStuff pages to layers, not the stack (kde#437961)
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * Rename BasicCellDelegate -> TextCellDelegate
  * Move mouse handling up to a common ancestor of the item
  * Fix flickering in table view (kde#436803)
  * Move mouse handling back to delegates
  * Fix initial sort order (kde#437449)
  * Fix newstuff action connection (kde#437702)
  * Do not position dialogs at fractional positions (kde#437805,kde#437804)
  * Fix sorting in Applications Detail View
  * Terminate process when pressing Delete (kde#436416)
  * [Applications Table] Prompt only on SIGKILL/SIGTERM
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Too many changes to list here
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- Changes since 5.21.4:
  * Also append fixedColumns  on initial load
  * Remove RowLayout from KillDialog DialogButtonBox (kde#435192)
  * Cleanup old controller if FaceLoader gets destroyed
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- Changes since 5.21.3:
  * Fix scrollbar overlapping configuration page (kde#434461)
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- Changes since 5.21.2:
  * The checkbox can be bigger than the text (kde#434009)
  * Ensure correct paddings (kde#434007)
  * Display existing search text in search field for application/process pages (kde#433324)
  * Set "ForceSaveOnDestroy" to true for Applications and Processes faces
  * Do not call a non-existing function (kde#433706)
  * Avoid showing "Processes: 0" in applications sidebar whilst loading (kde#433326)
  * Properly change colorSet (kde#434006)
  * Fix some visual bugs of the KillDialog (kde#433751)
  * Fix initial size of page download dialog (kde#433726)
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- Changes since 5.21.1:
  * Initialize m_pageData (kde#433532)
  * Add downloaded pages instantly again
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- Changes since 5.21.0:
  * Fix duplicate name columns appearing when configuring columns (kde#433216)
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * Layout tables correctly in rtl case
  * Improve dragging in rtl mode
  * Fix crashes relating to PageDialog (kde#432147)
  * Always open a dialog when it's loaded
  * Make table header height equal to Kirigami list item height
  * Remove rangeToX values from History page
  * ProcessSortFilter: Check if any column has been set rather than only uid
  * Use the correct total memory sensor for Application Details
  * Port ApplicationDetails to use HistoryProxySource
  * Use view color as background color for Application Details pane
  * Set a proper icon for the "search" actions in table faces
  * Create TreeDecoration dynamically
  * Use a Loader for deferring creation of dialogs in main files
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Too many changes to list here
* Thu Nov  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Use suse_update_desktop_file to fix build on Leap
* Thu Nov  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0 (actually a preview for 5.21)
* Mon Oct 26 2020 Luca Beltrame <lbeltrame@kde.org>
- Initial package
